'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

function _interopDefault (ex) { return (ex && (typeof ex === 'object') && 'default' in ex) ? ex['default'] : ex; }

var uniq = _interopDefault(require('lodash/uniq'));
var reactKnownProps = require('react-known-props');
var React = _interopDefault(require('react'));
var styled = require('styled-components');
var styled__default = _interopDefault(styled);
var omit = _interopDefault(require('lodash/omit'));
var kebabCase = _interopDefault(require('lodash/kebabCase'));
var PropTypes = _interopDefault(require('prop-types'));
var styledTools = require('styled-tools');
var hoistNonReactStatics = _interopDefault(require('hoist-non-react-statics'));
var constate = require('constate');
var ReactDOM = _interopDefault(require('react-dom'));
var uniqueId = _interopDefault(require('lodash/uniqueId'));

var cssProps = {
  alignContent: "align-content",
  alignSelf: "align-self",
  alignItems: "align-items",
  alignmentBaseline: "alignment-baseline",
  all: "all",
  animation: "animation",
  animationDelay: "animation-delay",
  animationDirection: "animation-direction",
  animationDuration: "animation-duration",
  animationFillMode: "animation-fill-mode",
  animationIterationCount: "animation-iteration-count",
  animationName: "animation-name",
  animationPlayState: "animation-play-state",
  animationTimingFunction: "animation-timing-function",
  appearance: "appearance",
  azimuth: "azimuth",
  backfaceVisibility: "backface-visibility",
  background: "background",
  backgroundAttachment: "background-attachment",
  backgroundBlendMode: "background-blend-mode",
  backgroundClip: "background-clip",
  backgroundColor: "background-color",
  backgroundImage: "background-image",
  backgroundImageTransform: "background-image-transform",
  backgroundOrigin: "background-origin",
  backgroundPosition: "background-position",
  backgroundRepeat: "background-repeat",
  backgroundSize: "background-size",
  baselineShift: "baseline-shift",
  blockSize: "block-size",
  blockStep: "block-step",
  blockStepAlign: "block-step-align",
  blockStepInsert: "block-step-insert",
  blockStepRound: "block-step-round",
  blockStepSize: "block-step-size",
  bookmarkLabel: "bookmark-label",
  bookmarkLevel: "bookmark-level",
  bookmarkState: "bookmark-state",
  border: "border",
  borderBlock: "border-block",
  borderBlockColor: "border-block-color",
  borderBlockEnd: "border-block-end",
  borderBlockEndColor: "border-block-end-color",
  borderBlockEndStyle: "border-block-end-style",
  borderBlockEndWidth: "border-block-end-width",
  borderBlockStart: "border-block-start",
  borderBlockStartColor: "border-block-start-color",
  borderBlockStartStyle: "border-block-start-style",
  borderBlockStartWidth: "border-block-start-width",
  borderBlockStyle: "border-block-style",
  borderBlockWidth: "border-block-width",
  borderBottom: "border-bottom",
  borderBottomColor: "border-bottom-color",
  borderBottomLeftRadius: "border-bottom-left-radius",
  borderBottomRightRadius: "border-bottom-right-radius",
  borderBottomStyle: "border-bottom-style",
  borderBottomWidth: "border-bottom-width",
  borderBoundary: "border-boundary",
  borderCollapse: "border-collapse",
  borderColor: "border-color",
  borderImage: "border-image",
  borderImageOutset: "border-image-outset",
  borderImageRepeat: "border-image-repeat",
  borderImageSlice: "border-image-slice",
  borderImageSource: "border-image-source",
  borderImageTransform: "border-image-transform",
  borderImageWidth: "border-image-width",
  borderInline: "border-inline",
  borderInlineColor: "border-inline-color",
  borderInlineEnd: "border-inline-end",
  borderInlineEndColor: "border-inline-end-color",
  borderInlineEndStyle: "border-inline-end-style",
  borderInlineEndWidth: "border-inline-end-width",
  borderInlineStart: "border-inline-start",
  borderInlineStartColor: "border-inline-start-color",
  borderInlineStartStyle: "border-inline-start-style",
  borderInlineStartWidth: "border-inline-start-width",
  borderInlineStyle: "border-inline-style",
  borderInlineWidth: "border-inline-width",
  borderLeft: "border-left",
  borderLeftColor: "border-left-color",
  borderLeftStyle: "border-left-style",
  borderLeftWidth: "border-left-width",
  borderRadius: "border-radius",
  borderRight: "border-right",
  borderRightColor: "border-right-color",
  borderRightStyle: "border-right-style",
  borderRightWidth: "border-right-width",
  borderSpacing: "border-spacing",
  borderStyle: "border-style",
  borderTop: "border-top",
  borderTopColor: "border-top-color",
  borderTopLeftRadius: "border-top-left-radius",
  borderTopRightRadius: "border-top-right-radius",
  borderTopStyle: "border-top-style",
  borderTopWidth: "border-top-width",
  borderWidth: "border-width",
  bottom: "bottom",
  boxDecorationBreak: "box-decoration-break",
  boxShadow: "box-shadow",
  boxSizing: "box-sizing",
  boxSnap: "box-snap",
  breakAfter: "break-after",
  breakBefore: "break-before",
  breakInside: "break-inside",
  captionSide: "caption-side",
  caret: "caret",
  caretAnimation: "caret-animation",
  caretColor: "caret-color",
  caretShape: "caret-shape",
  chains: "chains",
  clear: "clear",
  clip: "clip",
  clipPath: "clip-path",
  clipRule: "clip-rule",
  color: "color",
  colorAdjust: "color-adjust",
  colorInterpolationFilters: "color-interpolation-filters",
  columnCount: "column-count",
  columnFill: "column-fill",
  columnGap: "column-gap",
  columnRule: "column-rule",
  columnRuleColor: "column-rule-color",
  columnRuleStyle: "column-rule-style",
  columnRuleWidth: "column-rule-width",
  columnSpan: "column-span",
  columnWidth: "column-width",
  columns: "columns",
  contain: "contain",
  content: "content",
  continue: "continue",
  counterIncrement: "counter-increment",
  counterReset: "counter-reset",
  counterSet: "counter-set",
  cue: "cue",
  cueAfter: "cue-after",
  cueBefore: "cue-before",
  cursor: "cursor",
  direction: "direction",
  display: "display",
  dominantBaseline: "dominant-baseline",
  elevation: "elevation",
  emptyCells: "empty-cells",
  fill: "fill",
  fillBreak: "fill-break",
  fillColor: "fill-color",
  fillImage: "fill-image",
  fillOpacity: "fill-opacity",
  fillOrigin: "fill-origin",
  fillPosition: "fill-position",
  fillRepeat: "fill-repeat",
  fillRule: "fill-rule",
  fillSize: "fill-size",
  filter: "filter",
  flex: "flex",
  flexBasis: "flex-basis",
  flexDirection: "flex-direction",
  flexFlow: "flex-flow",
  flexGrow: "flex-grow",
  flexShrink: "flex-shrink",
  flexWrap: "flex-wrap",
  float: "float",
  floatDefer: "float-defer",
  floatOffset: "float-offset",
  floatReference: "float-reference",
  floodColor: "flood-color",
  floodOpacity: "flood-opacity",
  flow: "flow",
  flowFrom: "flow-from",
  flowInto: "flow-into",
  font: "font",
  fontFamily: "font-family",
  fontFeatureSettings: "font-feature-settings",
  fontKerning: "font-kerning",
  fontLanguageOverride: "font-language-override",
  fontMaxSize: "font-max-size",
  fontMinSize: "font-min-size",
  fontOpticalSizing: "font-optical-sizing",
  fontPalette: "font-palette",
  fontPresentation: "font-presentation",
  fontSize: "font-size",
  fontSizeAdjust: "font-size-adjust",
  fontStretch: "font-stretch",
  fontStyle: "font-style",
  fontSynthesis: "font-synthesis",
  fontVariant: "font-variant",
  fontVariantAlternates: "font-variant-alternates",
  fontVariantCaps: "font-variant-caps",
  fontVariantEastAsian: "font-variant-east-asian",
  fontVariantLigatures: "font-variant-ligatures",
  fontVariantNumeric: "font-variant-numeric",
  fontVariantPosition: "font-variant-position",
  fontVariationSettings: "font-variation-settings",
  fontWeight: "font-weight",
  footnoteDisplay: "footnote-display",
  footnotePolicy: "footnote-policy",
  gap: "gap",
  glyphOrientationVertical: "glyph-orientation-vertical",
  grid: "grid",
  gridArea: "grid-area",
  gridAutoColumns: "grid-auto-columns",
  gridAutoFlow: "grid-auto-flow",
  gridAutoRows: "grid-auto-rows",
  gridColumn: "grid-column",
  gridColumnEnd: "grid-column-end",
  gridColumnGap: "grid-column-gap",
  gridColumnStart: "grid-column-start",
  gridGap: "grid-gap",
  gridRow: "grid-row",
  gridRowEnd: "grid-row-end",
  gridRowGap: "grid-row-gap",
  gridRowStart: "grid-row-start",
  gridTemplate: "grid-template",
  gridTemplateAreas: "grid-template-areas",
  gridTemplateColumns: "grid-template-columns",
  gridTemplateRows: "grid-template-rows",
  hangingPunctuation: "hanging-punctuation",
  height: "height",
  hyphenateCharacter: "hyphenate-character",
  hyphenateLimitChars: "hyphenate-limit-chars",
  hyphenateLimitLast: "hyphenate-limit-last",
  hyphenateLimitLines: "hyphenate-limit-lines",
  hyphenateLimitZone: "hyphenate-limit-zone",
  hyphens: "hyphens",
  imageOrientation: "image-orientation",
  imageResolution: "image-resolution",
  initialLetter: "initial-letter",
  initialLetterAlign: "initial-letter-align",
  initialLetterWrap: "initial-letter-wrap",
  inlineSize: "inline-size",
  inset: "inset",
  insetBlock: "inset-block",
  insetBlockEnd: "inset-block-end",
  insetBlockStart: "inset-block-start",
  insetInline: "inset-inline",
  insetInlineEnd: "inset-inline-end",
  insetInlineStart: "inset-inline-start",
  isolation: "isolation",
  justifyContent: "justify-content",
  justifyItems: "justify-items",
  justifySelf: "justify-self",
  left: "left",
  letterSpacing: "letter-spacing",
  lightingColor: "lighting-color",
  lineBreak: "line-break",
  lineGrid: "line-grid",
  lineHeight: "line-height",
  lineHeightStep: "line-height-step",
  lineSnap: "line-snap",
  listStyle: "list-style",
  listStyleImage: "list-style-image",
  listStylePosition: "list-style-position",
  listStyleType: "list-style-type",
  margin: "margin",
  marginBlock: "margin-block",
  marginBlockEnd: "margin-block-end",
  marginBlockStart: "margin-block-start",
  marginBottom: "margin-bottom",
  marginInline: "margin-inline",
  marginInlineEnd: "margin-inline-end",
  marginInlineStart: "margin-inline-start",
  marginLeft: "margin-left",
  marginRight: "margin-right",
  marginTop: "margin-top",
  marker: "marker",
  markerEnd: "marker-end",
  markerKnockoutLeft: "marker-knockout-left",
  markerKnockoutRight: "marker-knockout-right",
  markerMid: "marker-mid",
  markerPattern: "marker-pattern",
  markerSegment: "marker-segment",
  markerSide: "marker-side",
  markerStart: "marker-start",
  marqueeDirection: "marquee-direction",
  marqueeLoop: "marquee-loop",
  marqueeSpeed: "marquee-speed",
  marqueeStyle: "marquee-style",
  mask: "mask",
  maskBorder: "mask-border",
  maskBorderMode: "mask-border-mode",
  maskBorderOutset: "mask-border-outset",
  maskBorderRepeat: "mask-border-repeat",
  maskBorderSlice: "mask-border-slice",
  maskBorderSource: "mask-border-source",
  maskBorderWidth: "mask-border-width",
  maskClip: "mask-clip",
  maskComposite: "mask-composite",
  maskImage: "mask-image",
  maskMode: "mask-mode",
  maskOrigin: "mask-origin",
  maskPosition: "mask-position",
  maskRepeat: "mask-repeat",
  maskSize: "mask-size",
  maskType: "mask-type",
  maxBlockSize: "max-block-size",
  maxHeight: "max-height",
  maxInlineSize: "max-inline-size",
  maxLines: "max-lines",
  maxWidth: "max-width",
  minBlockSize: "min-block-size",
  minHeight: "min-height",
  minInlineSize: "min-inline-size",
  minWidth: "min-width",
  mixBlendMode: "mix-blend-mode",
  navDown: "nav-down",
  navLeft: "nav-left",
  navRight: "nav-right",
  navUp: "nav-up",
  objectFit: "object-fit",
  objectPosition: "object-position",
  offset: "offset",
  offsetAfter: "offset-after",
  offsetAnchor: "offset-anchor",
  offsetBefore: "offset-before",
  offsetDistance: "offset-distance",
  offsetEnd: "offset-end",
  offsetPath: "offset-path",
  offsetPosition: "offset-position",
  offsetRotate: "offset-rotate",
  offsetStart: "offset-start",
  opacity: "opacity",
  order: "order",
  orphans: "orphans",
  outline: "outline",
  outlineColor: "outline-color",
  outlineOffset: "outline-offset",
  outlineStyle: "outline-style",
  outlineWidth: "outline-width",
  overflow: "overflow",
  overflowStyle: "overflow-style",
  overflowWrap: "overflow-wrap",
  overflowX: "overflow-x",
  overflowY: "overflow-y",
  padding: "padding",
  paddingBlock: "padding-block",
  paddingBlockEnd: "padding-block-end",
  paddingBlockStart: "padding-block-start",
  paddingBottom: "padding-bottom",
  paddingInline: "padding-inline",
  paddingInlineEnd: "padding-inline-end",
  paddingInlineStart: "padding-inline-start",
  paddingLeft: "padding-left",
  paddingRight: "padding-right",
  paddingTop: "padding-top",
  page: "page",
  pageBreakAfter: "page-break-after",
  pageBreakBefore: "page-break-before",
  pageBreakInside: "page-break-inside",
  pause: "pause",
  pauseAfter: "pause-after",
  pauseBefore: "pause-before",
  perspective: "perspective",
  perspectiveOrigin: "perspective-origin",
  pitch: "pitch",
  pitchRange: "pitch-range",
  placeContent: "place-content",
  placeItems: "place-items",
  placeSelf: "place-self",
  playDuring: "play-during",
  pointerEvents: "pointer-events",
  position: "position",
  presentationLevel: "presentation-level",
  quotes: "quotes",
  regionFragment: "region-fragment",
  resize: "resize",
  rest: "rest",
  restAfter: "rest-after",
  restBefore: "rest-before",
  richness: "richness",
  right: "right",
  rotation: "rotation",
  rotationPoint: "rotation-point",
  rowGap: "row-gap",
  rubyAlign: "ruby-align",
  rubyMerge: "ruby-merge",
  rubyPosition: "ruby-position",
  running: "running",
  scrollBehavior: "scroll-behavior",
  scrollPadding: "scroll-padding",
  scrollPaddingBlock: "scroll-padding-block",
  scrollPaddingBlockEnd: "scroll-padding-block-end",
  scrollPaddingBlockStart: "scroll-padding-block-start",
  scrollPaddingBottom: "scroll-padding-bottom",
  scrollPaddingInline: "scroll-padding-inline",
  scrollPaddingInlineEnd: "scroll-padding-inline-end",
  scrollPaddingInlineStart: "scroll-padding-inline-start",
  scrollPaddingLeft: "scroll-padding-left",
  scrollPaddingRight: "scroll-padding-right",
  scrollPaddingTop: "scroll-padding-top",
  scrollSnapAlign: "scroll-snap-align",
  scrollSnapMargin: "scroll-snap-margin",
  scrollSnapMarginBlock: "scroll-snap-margin-block",
  scrollSnapMarginBlockEnd: "scroll-snap-margin-block-end",
  scrollSnapMarginBlockStart: "scroll-snap-margin-block-start",
  scrollSnapMarginBottom: "scroll-snap-margin-bottom",
  scrollSnapMarginInline: "scroll-snap-margin-inline",
  scrollSnapMarginInlineEnd: "scroll-snap-margin-inline-end",
  scrollSnapMarginInlineStart: "scroll-snap-margin-inline-start",
  scrollSnapMarginLeft: "scroll-snap-margin-left",
  scrollSnapMarginRight: "scroll-snap-margin-right",
  scrollSnapMarginTop: "scroll-snap-margin-top",
  scrollSnapStop: "scroll-snap-stop",
  scrollSnapType: "scroll-snap-type",
  scrollbarGutter: "scrollbar-gutter",
  shapeImageThreshold: "shape-image-threshold",
  shapeInside: "shape-inside",
  shapeMargin: "shape-margin",
  shapeOutside: "shape-outside",
  size: "size",
  speak: "speak",
  speakAs: "speak-as",
  speakHeader: "speak-header",
  speakNumeral: "speak-numeral",
  speakPunctuation: "speak-punctuation",
  speechRate: "speech-rate",
  stress: "stress",
  stringSet: "string-set",
  stroke: "stroke",
  strokeAlign: "stroke-align",
  strokeAlignment: "stroke-alignment",
  strokeBreak: "stroke-break",
  strokeColor: "stroke-color",
  strokeDashCorner: "stroke-dash-corner",
  strokeDashJustify: "stroke-dash-justify",
  strokeDashadjust: "stroke-dashadjust",
  strokeDasharray: "stroke-dasharray",
  strokeDashcorner: "stroke-dashcorner",
  strokeDashoffset: "stroke-dashoffset",
  strokeImage: "stroke-image",
  strokeLinecap: "stroke-linecap",
  strokeLinejoin: "stroke-linejoin",
  strokeMiterlimit: "stroke-miterlimit",
  strokeOpacity: "stroke-opacity",
  strokeOrigin: "stroke-origin",
  strokePosition: "stroke-position",
  strokeRepeat: "stroke-repeat",
  strokeSize: "stroke-size",
  strokeWidth: "stroke-width",
  tabSize: "tab-size",
  tableLayout: "table-layout",
  textAlign: "text-align",
  textAlignAll: "text-align-all",
  textAlignLast: "text-align-last",
  textCombineUpright: "text-combine-upright",
  textDecoration: "text-decoration",
  textDecorationColor: "text-decoration-color",
  textDecorationLine: "text-decoration-line",
  textDecorationSkip: "text-decoration-skip",
  textDecorationStyle: "text-decoration-style",
  textEmphasis: "text-emphasis",
  textEmphasisColor: "text-emphasis-color",
  textEmphasisPosition: "text-emphasis-position",
  textEmphasisStyle: "text-emphasis-style",
  textIndent: "text-indent",
  textJustify: "text-justify",
  textOrientation: "text-orientation",
  textOverflow: "text-overflow",
  textShadow: "text-shadow",
  textSpaceCollapse: "text-space-collapse",
  textSpaceTrim: "text-space-trim",
  textSpacing: "text-spacing",
  textTransform: "text-transform",
  textUnderlinePosition: "text-underline-position",
  textWrap: "text-wrap",
  top: "top",
  transform: "transform",
  transformBox: "transform-box",
  transformOrigin: "transform-origin",
  transformStyle: "transform-style",
  transition: "transition",
  transitionDelay: "transition-delay",
  transitionDuration: "transition-duration",
  transitionProperty: "transition-property",
  transitionTimingFunction: "transition-timing-function",
  unicodeBidi: "unicode-bidi",
  userSelect: "user-select",
  verticalAlign: "vertical-align",
  visibility: "visibility",
  voiceBalance: "voice-balance",
  voiceDuration: "voice-duration",
  voiceFamily: "voice-family",
  voicePitch: "voice-pitch",
  voiceRange: "voice-range",
  voiceRate: "voice-rate",
  voiceStress: "voice-stress",
  voiceVolume: "voice-volume",
  volume: "volume",
  whiteSpace: "white-space",
  widows: "widows",
  width: "width",
  willChange: "will-change",
  wordBreak: "word-break",
  wordSpacing: "word-spacing",
  wordWrap: "word-wrap",
  wrapAfter: "wrap-after",
  wrapBefore: "wrap-before",
  wrapFlow: "wrap-flow",
  wrapInside: "wrap-inside",
  wrapThrough: "wrap-through",
  writingMode: "writing-mode",
  zIndex: "z-index"
};

var classCallCheck = function (instance, Constructor) {
  if (!(instance instanceof Constructor)) {
    throw new TypeError("Cannot call a class as a function");
  }
};

var _extends = Object.assign || function (target) {
  for (var i = 1; i < arguments.length; i++) {
    var source = arguments[i];

    for (var key in source) {
      if (Object.prototype.hasOwnProperty.call(source, key)) {
        target[key] = source[key];
      }
    }
  }

  return target;
};

var inherits = function (subClass, superClass) {
  if (typeof superClass !== "function" && superClass !== null) {
    throw new TypeError("Super expression must either be null or a function, not " + typeof superClass);
  }

  subClass.prototype = Object.create(superClass && superClass.prototype, {
    constructor: {
      value: subClass,
      enumerable: false,
      writable: true,
      configurable: true
    }
  });
  if (superClass) Object.setPrototypeOf ? Object.setPrototypeOf(subClass, superClass) : subClass.__proto__ = superClass;
};

var objectWithoutProperties = function (obj, keys) {
  var target = {};

  for (var i in obj) {
    if (keys.indexOf(i) >= 0) continue;
    if (!Object.prototype.hasOwnProperty.call(obj, i)) continue;
    target[i] = obj[i];
  }

  return target;
};

var possibleConstructorReturn = function (self, call) {
  if (!self) {
    throw new ReferenceError("this hasn't been initialised - super() hasn't been called");
  }

  return call && (typeof call === "object" || typeof call === "function") ? call : self;
};

var pickCssProps = function pickCssProps(props) {
  return Object.keys(props).reduce(function (finalObject, key) {
    if (cssProps[key]) {
      var _babelHelpers$extends;

      return _extends({}, finalObject, (_babelHelpers$extends = {}, _babelHelpers$extends[key] = props[key], _babelHelpers$extends));
    }
    return finalObject;
  }, "");
};

var parseTag = function parseTag(tag) {
  if (Array.isArray(tag)) {
    var tags = tag.filter(function (currentTag, i) {
      return typeof currentTag !== "string" || i === tag.length - 1;
    });
    return tags.length <= 1 ? tags[0] || "span" : tags;
  }
  return tag || "span";
};

var parseClassName = function parseClassName(className) {
  if (!className) return className;
  return uniq(className.split(" ")).join(" ");
};

var pickHTMLProps = function pickHTMLProps(tagName, props) {
  var allowedProps = [].concat(reactKnownProps.getElementProps(tagName, { legacy: true }), reactKnownProps.getEventProps());

  var testProp = function testProp(prop) {
    return allowedProps.indexOf(prop) >= 0 || /^data-.+/.test(prop);
  };

  return Object.keys(props).reduce(function (finalProps, key) {
    var _ref;

    return _extends({}, finalProps, testProp(key) ? (_ref = {}, _ref[key] = props[key], _ref) : {});
  }, {});
};

/* eslint-disable no-param-reassign */

// eslint-disable-next-line no-use-before-define
var As = function As(_ref) {
  var nextAs = _ref.nextAs,
      props = objectWithoutProperties(_ref, ["nextAs"]);
  return render(_extends({}, props, { as: nextAs }));
};

var render = function render(_ref2) {
  var t = _ref2.as,
      props = objectWithoutProperties(_ref2, ["as"]);

  var T = parseTag(t);

  if (Array.isArray(T)) {
    var _T$filter = T.filter(function (x) {
      return x !== As;
    }),
        First = _T$filter[0],
        others = _T$filter.slice(1);

    return React.createElement(First, _extends({}, props, { as: As, nextAs: others }));
  }

  var style = pickCssProps(props);
  var className = parseClassName(props.className);

  if (typeof T === "string") {
    var dangerouslySetInnerHTML = props.dangerouslySetInnerHTML,
        children = props.children;

    var propsWithStyle = _extends({}, props, style ? { style: style } : {});
    var otherProps = dangerouslySetInnerHTML ? { dangerouslySetInnerHTML: dangerouslySetInnerHTML } : {};
    var allProps = _extends({}, pickHTMLProps(T, propsWithStyle), otherProps, {
      className: className
    });

    return React.createElement(
      T,
      _extends({}, allProps, { ref: props.elementRef }),
      children
    );
  }

  return React.createElement(T, _extends({}, props, { className: className }, style ? { style: style } : {}));
};

var as = function as(asComponents) {
  return function (WrappedComponent) {
    var target = styled.isStyledComponent(WrappedComponent) ? WrappedComponent.target : WrappedComponent;

    var components = [].concat(WrappedComponent, asComponents);

    var getComponentName = function getComponentName(component) {
      return component.displayName || component.name || component;
    };

    var displayName = getComponentName(WrappedComponent) + ".as(" + [].concat(asComponents).map(getComponentName) + ")";

    var defineProperties = function defineProperties(scope) {
      scope.asComponents = asComponents;
      scope.as = function (otherComponents) {
        return as(otherComponents)(scope);
      };
      return scope;
    };

    if (asComponents === target.asComponents) {
      return defineProperties(WrappedComponent);
    }

    var getAs = function getAs(props) {
      return components.concat(props.as || [], props.nextAs || []);
    };

    var Component = function Component(props) {
      return render(_extends({}, omit(props, "nextAs"), { as: getAs(props) }));
    };

    Component.displayName = displayName;

    if (styled.isStyledComponent(WrappedComponent)) {
      Component = WrappedComponent.withComponent(Component);
      Component.styledComponentId = WrappedComponent.styledComponentId;
      Component.displayName = "Styled(" + displayName + ")";
    }

    return defineProperties(Component);
  };
};

var bool = function bool(cssProp, validComponentProps) {
  return function (props) {
    var keys = Object.keys(props).filter(function (k) {
      return validComponentProps.indexOf(k) >= 0;
    }).filter(function (k) {
      return !!props[k];
    }).map(kebabCase);
    if (keys.length) {
      return cssProp + ": " + keys.join(" ") + ";";
    }
    return "";
  };
};

var value = function value(cssProp, componentProp) {
  return function (props) {
    var v = props[componentProp];
    if (typeof v === "undefined") return "";
    if (typeof v === "number") {
      return cssProp + ": " + v + "px;";
    }
    return cssProp + ": " + v + ";";
  };
};

var positions = ["static", "absolute", "fixed", "relative", "sticky"];

var Component = function Component(_ref) {
  var T = _ref.as,
      props = objectWithoutProperties(_ref, ["as"]);
  return React.createElement(T, props);
};

var Base = styled__default(Component).withConfig({
  displayName: "Base"
})(["margin:0;padding:0;border:0;font-size:100%;font-family:inherit;vertical-align:baseline;box-sizing:border-box;", ";&&&{", ";}"], styledTools.prop("theme.Base"), bool("position", positions));

var asTypes = [PropTypes.func, PropTypes.string];

Base.propTypes = _extends({
  as: PropTypes.oneOfType([].concat(asTypes, [PropTypes.arrayOf(PropTypes.oneOfType(asTypes))]))
}, positions.reduce(function (obj, position) {
  var _babelHelpers$extends;

  return _extends({}, obj, (_babelHelpers$extends = {}, _babelHelpers$extends[position] = PropTypes.bool, _babelHelpers$extends));
}, {}));

var Base$1 = as("div")(Base);

var SQRT2 = 1.41421356237;

var Arrow = styled__default(Base$1).withConfig({
  displayName: "Arrow"
})(["display:inline-flex;width:1em;height:1em;overflow:hidden;color:rgba(0,0,0,0.85);align-items:center;justify-content:center;border-bottom-width:0 !important;border-right-width:0 !important;border-left-width:0 !important;box-sizing:content-box;transform:rotateZ(", "deg);&:after{content:\"\";background-color:currentcolor;border:inherit;border-width:1px;border-top-width:0;border-left-width:0;margin-bottom:100%;width:calc(100% / ", ");height:calc(100% / ", ");transform:rotateZ(45deg);}", ";"], styledTools.prop("angle"), SQRT2, SQRT2, styledTools.prop("theme.Arrow"));

Arrow.propTypes = {
  angle: PropTypes.number
};

Arrow.defaultProps = {
  angle: 0
};

var Arrow$1 = as("div")(Arrow);

var Component$1 = function (_React$Component) {
  inherits(Component, _React$Component);

  function Component() {
    var _temp, _this, _ret;

    classCallCheck(this, Component);

    for (var _len = arguments.length, args = Array(_len), _key = 0; _key < _len; _key++) {
      args[_key] = arguments[_key];
    }

    return _ret = (_temp = (_this = possibleConstructorReturn(this, _React$Component.call.apply(_React$Component, [this].concat(args))), _this), _this.handleKeyDown = function (e) {
      if (e.key === "Escape" && _this.props.hide) {
        _this.props.hide();
      }
    }, _temp), possibleConstructorReturn(_this, _ret);
  }

  Component.prototype.componentDidMount = function componentDidMount() {
    var _props = this.props,
        visible = _props.visible,
        hideOnEsc = _props.hideOnEsc;

    if (visible && hideOnEsc) {
      document.body.addEventListener("keydown", this.handleKeyDown);
    }
  };

  Component.prototype.componentDidUpdate = function componentDidUpdate(prevProps) {
    var _props2 = this.props,
        visible = _props2.visible,
        hideOnEsc = _props2.hideOnEsc;

    if (prevProps.visible !== visible && hideOnEsc) {
      var addOrRemove = visible ? "addEventListener" : "removeEventListener";
      document.body[addOrRemove]("keydown", this.handleKeyDown);
    }
  };

  Component.prototype.render = function render() {
    var _props3 = this.props,
        visible = _props3.visible,
        styleProp = _props3.styleProp,
        destroy = _props3.destroy;


    if (destroy) {
      return visible ? React.createElement(Base$1, this.props) : null;
    }

    return React.createElement(Base$1, _extends({
      "aria-hidden": !visible,
      hidden: !visible && styleProp === "display"
    }, this.props));
  };

  return Component;
}(React.Component);

hoistNonReactStatics(Component$1, Base$1);

var Hidden = styled__default(Component$1).withConfig({
  displayName: "Hidden"
})(["", ";", ";"], styledTools.ifNotProp("visible", styledTools.switchProp("styleProp", {
  visibility: "visibility: hidden !important",
  opacity: "opacity: 0 !important",
  display: "display: none !important"
})), styledTools.prop("theme.Hidden"));

Hidden.propTypes = {
  hide: PropTypes.func,
  hideOnEsc: PropTypes.bool,
  visible: PropTypes.bool,
  destroy: PropTypes.bool,
  styleProp: PropTypes.oneOf(["display", "visibility", "opacity"])
};

Hidden.defaultProps = {
  styleProp: "display"
};

var Hidden$1 = as("div")(Hidden);

var initialState = { visible: false };

var toggle = function toggle() {
  return function (state) {
    return { visible: !state.visible };
  };
};

var show = function show() {
  return function () {
    return { visible: true };
  };
};

var hide = function hide() {
  return function () {
    return { visible: false };
  };
};

var HiddenContainer = function HiddenContainer(props) {
  return React.createElement(constate.Container, _extends({}, props, {
    initialState: _extends({}, initialState, props.initialState),
    actions: _extends({ toggle: toggle, show: show, hide: hide }, props.actions)
  }));
};

HiddenContainer.propTypes = {
  initialState: PropTypes.object,
  actions: PropTypes.objectOf(PropTypes.func)
};

var callAll = function callAll() {
  for (var _len = arguments.length, fns = Array(_len), _key = 0; _key < _len; _key++) {
    fns[_key] = arguments[_key];
  }

  return function () {
    for (var _len2 = arguments.length, args = Array(_len2), _key2 = 0; _key2 < _len2; _key2++) {
      args[_key2] = arguments[_key2];
    }

    return fns.forEach(function (fn) {
      return fn && fn.apply(undefined, args);
    });
  };
};

var Component$2 = function Component(_ref) {
  var onClick = _ref.onClick,
      props = objectWithoutProperties(_ref, ["onClick"]);
  return React.createElement(Base$1, _extends({ onClick: callAll(props.hide, onClick) }, props));
};

var HiddenHide = styled__default(Component$2).withConfig({
  displayName: "HiddenHide"
})(["", ";"], styledTools.prop("theme.HiddenHide"));

HiddenHide.propTypes = {
  hide: PropTypes.func.isRequired,
  onClick: PropTypes.func
};

var HiddenHide$1 = as("button")(HiddenHide);

var Component$3 = function Component(_ref) {
  var onClick = _ref.onClick,
      props = objectWithoutProperties(_ref, ["onClick"]);
  return React.createElement(Base$1, _extends({ onClick: callAll(props.show, onClick) }, props));
};

var HiddenShow = styled__default(Component$3).withConfig({
  displayName: "HiddenShow"
})(["", ";"], styledTools.prop("theme.HiddenShow"));

HiddenShow.propTypes = {
  show: PropTypes.func.isRequired,
  onClick: PropTypes.func
};

var HiddenShow$1 = as("button")(HiddenShow);

var Component$4 = function Component(_ref) {
  var onClick = _ref.onClick,
      props = objectWithoutProperties(_ref, ["onClick"]);
  return React.createElement(Base$1, _extends({ onClick: callAll(props.toggle, onClick) }, props));
};

var HiddenToggle = styled__default(Component$4).withConfig({
  displayName: "HiddenToggle"
})(["", ";"], styledTools.prop("theme.HiddenToggle"));

HiddenToggle.propTypes = {
  toggle: PropTypes.func.isRequired,
  onClick: PropTypes.func
};

var HiddenToggle$1 = as("button")(HiddenToggle);

Hidden$1.Container = HiddenContainer;
Hidden$1.Hide = HiddenHide$1;
Hidden$1.Show = HiddenShow$1;
Hidden$1.Toggle = HiddenToggle$1;

var Backdrop = styled__default(Hidden$1).withConfig({
  displayName: "Backdrop"
})(["position:fixed;top:0;left:0;width:100%;height:100%;background-color:rgba(0,0,0,0.3);z-index:998;-webkit-tap-highlight-color:rgba(0,0,0,0);-moz-tap-highlight-color:rgba(0,0,0,0);", ";"], styledTools.prop("theme.Backdrop"));

Backdrop.defaultProps = {
  role: "button",
  tabIndex: -1
};

var Backdrop$1 = as("div")(Backdrop);

var Block = styled__default(Base$1).withConfig({
  displayName: "Block"
})(["display:block;", ";"], styledTools.prop("theme.Block"));

var Block$1 = as("div")(Block);

var Blockquote = styled__default(Base$1).withConfig({
  displayName: "Blockquote"
})(["padding:0.5em 1em;"]);

var Blockquote$1 = as("blockquote")(Blockquote);

var Box = styled__default(Base$1).withConfig({
  displayName: "Box"
})(["border:1px solid rgba(0,0,0,0.3);border-radius:0.25em;", ";"], styledTools.prop("theme.Box"));

var Box$1 = as("div")(Box);

var handleKeyPress = function handleKeyPress(e) {
  if (e.charCode === 32 || e.charCode === 13) {
    e.preventDefault();
    e.target.click();
  }
};

var Button = styled__default(Box$1).withConfig({
  displayName: "Button"
})(["display:inline-flex;position:relative;flex:none;appearance:none;user-select:none;outline:none;align-items:center;white-space:nowrap;justify-content:center;text-decoration:none;color:inherit;cursor:pointer;background-color:rgba(0,0,0,0.03);height:2.5em;min-width:2.5em;padding:0 0.68em;&:hover,&:focus{box-shadow:inset 0 0 999em rgba(0,0,0,0.1);}&:active,&.active{box-shadow:inset 0 0 999em rgba(0,0,0,0.2);}&:after{display:none;content:\"\";position:absolute;top:0;right:0;bottom:0;left:0;border-radius:inherit;background-color:rgba(255,255,255,0.35);}&[disabled]{pointer-events:none;&:after{display:block;}}&:not(button):not(select):not(input){display:inline-grid;grid-gap:0.68em;grid-auto-flow:column;align-content:center;}", ";"], styledTools.prop("theme.Button"));

Button.defaultProps = {
  role: "button",
  tabIndex: 0,
  onKeyPress: handleKeyPress
};

var Button$1 = as("div")(Button);

var Card = styled__default(Base$1).withConfig({
  displayName: "Card"
})(["position:relative;display:inline-grid;background-color:white;grid-gap:1rem;padding:1rem 0;&&& > *{margin:0 1rem;}&&& > img{margin:0;&:first-child{margin-top:-1rem;}&:last-child{margin-bottom:-1rem;}}", ";"], styledTools.prop("theme.Card"));

var Card$1 = as("div")(Card);

var Component$5 = function Component(props) {
  if (props.block) {
    return React.createElement(
      Base$1,
      _extends({ as: "pre" }, props),
      React.createElement(
        "code",
        { className: props.codeClassName },
        props.children
      )
    );
  }
  var className = props.codeClassName ? (props.className + " " + props.codeClassName).trim() : ("" + props.className).trim();
  return React.createElement(Base$1, _extends({ as: "code" }, props, { className: className }));
};

var Code = styled__default(Base$1).withConfig({
  displayName: "Code"
})(["background-color:rgba(0,0,0,0.05);font-family:monospace;white-space:pre-wrap;word-wrap:break-word;padding:", ";code{display:block;padding:1em;}", ";"], styledTools.ifProp("block", "0", "0.25em 0.35em"), styledTools.prop("theme.Code"));

Code.propTypes = {
  block: PropTypes.bool,
  codeClassName: PropTypes.string
};

var Code$1 = as(Component$5)(Code);

var Divider = styled__default(Base$1).withConfig({
  displayName: "Divider"
})(["border:1px solid currentcolor;opacity:0.2;", ";", ";"], styledTools.ifProp("vertical", styled.css(["margin:0 1rem;min-height:100%;width:0;border-width:0 0 0 1px;"]), styled.css(["margin:1rem 0;height:0;border-width:1px 0 0 0;"])), styledTools.prop("theme.Divider"));

Divider.propTypes = {
  vertical: PropTypes.bool
};

var Divider$1 = as("div")(Divider);

var Field = styled__default(Base$1).withConfig({
  displayName: "Field"
})(["display:flex;flex-direction:column;flex:1;label{padding-bottom:0.5em;}> *:not(label):not(:last-child){margin-bottom:0.5em;}", ";"], styledTools.prop("theme.Field"));

var Field$1 = as("div")(Field);

var Fit = styled__default(Base$1).withConfig({
  displayName: "Fit"
})(["position:absolute;top:0;right:0;bottom:0;left:0;", ";"], styledTools.prop("theme.Fit"));

var Fit$1 = as("div")(Fit);

var directions = ["row", "column", "rowReverse", "columnReverse"];
var wraps = ["nowrap", "wrap", "wrapReverse"];

var Flex = styled__default(Base$1).withConfig({
  displayName: "Flex"
})(["display:flex;&&&{", ";", ";}", ";"], bool("flex-direction", directions), bool("flex-wrap", wraps), styledTools.prop("theme.Flex"));

Flex.propTypes = {
  row: PropTypes.bool,
  column: PropTypes.bool,
  rowReverse: PropTypes.bool,
  columnReverse: PropTypes.bool,
  nowrap: PropTypes.bool,
  wrap: PropTypes.bool,
  wrapReverse: PropTypes.bool
};

var Flex$1 = as("div")(Flex);

var Grid = styled__default(Base$1).withConfig({
  displayName: "Grid"
})(["display:grid;&&&{", " ", " ", " ", " ", " ", " ", " ", "}", ";"], bool("grid-auto-flow", ["row", "column", "dense"]), value("grid-gap", "gap"), value("grid-template", "template"), value("grid-template-areas", "areas"), value("grid-template-columns", "columns"), value("grid-template-rows", "rows"), value("grid-auto-columns", "autoColumns"), value("grid-auto-rows", "autoRows"), styledTools.prop("theme.Grid"));

var valueType = PropTypes.oneOfType([PropTypes.string, PropTypes.number]);

Grid.propTypes = {
  row: PropTypes.bool,
  column: PropTypes.bool,
  dense: PropTypes.bool,
  gap: valueType,
  template: valueType,
  areas: valueType,
  columns: valueType,
  rows: valueType,
  autoColumns: valueType,
  autoRows: valueType
};

var Grid$1 = as("div")(Grid);

var GridItem = styled__default(Base$1).withConfig({
  displayName: "GridItem"
})(["&&&{", ";", ";", ";", ";", ";", ";", ";}", ";"], value("grid-area", "area"), value("grid-column", "column"), value("grid-row", "row"), value("grid-column-start", "columnStart"), value("grid-column-end", "columnEnd"), value("grid-row-start", "rowStart"), value("grid-row-end", "rowEnd"), styledTools.prop("theme.GridItem"));

var valueType$1 = PropTypes.oneOfType([PropTypes.string, PropTypes.number]);

GridItem.propTypes = {
  area: valueType$1,
  column: valueType$1,
  row: valueType$1,
  columnStart: valueType$1,
  columnEnd: valueType$1,
  rowStart: valueType$1,
  rowEnd: valueType$1
};

var GridItem$1 = as("div")(GridItem);

Grid$1.Item = GridItem$1;

var GroupItem = styled__default(Box$1).withConfig({
  displayName: "GroupItem"
})(["", ";"], styledTools.prop("theme.GroupItem"));

var GroupItem$1 = as("div")(GroupItem);

var verticalAt = function verticalAt(pass, fail) {
  return styledTools.ifProp("verticalAt", styled.css(["@media (min-width:", "px){", ";}@media (max-width:", "px){", ";}"], styledTools.withProp("verticalAt", function (x) {
    return x + 1;
  }), fail, styledTools.prop("verticalAt"), pass), fail);
};

var Group = styled__default(Base$1).withConfig({
  displayName: "Group"
})(["display:flex;flex-direction:", ";", ";> *,> * ", "{min-height:2.5em;height:auto;}> *:not(:first-child):not(:last-child),> *:not(:first-child):not(:last-child) ", "{border-radius:0;", ";}> *:first-child,> *:first-child ", "{border-bottom-right-radius:0;", ";}> *:last-child,> *:last-child ", "{border-top-left-radius:0;", ";}", ";"], styledTools.ifProp("vertical", "column", "row"), verticalAt("flex-direction: column"), GroupItem$1, GroupItem$1, verticalAt(styled.css(["border-top-width:0;"]), styled.css(["border-", "-width:0;"], styledTools.ifProp("vertical", "top", "left"))), GroupItem$1, verticalAt(styled.css(["border-bottom-left-radius:0;"]), styled.css(["border-", "-radius:0;"], styledTools.ifProp("vertical", "bottom-left", "top-right"))), GroupItem$1, verticalAt(styled.css(["border-top-width:0;border-top-right-radius:0;"]), styled.css(["border-", "-width:0;border-", "-radius:0;"], styledTools.ifProp("vertical", "top", "left"), styledTools.ifProp("vertical", "top-right", "bottom-left"))), styledTools.prop("theme.Group"));

Group.propTypes = {
  vertical: PropTypes.bool,
  verticalAt: PropTypes.number
};

Group.defaultProps = {
  role: "group"
};

var Group$1 = as("div")(Group);

Group$1.Item = GroupItem$1;

var getUnderlyingElement = function getUnderlyingElement(props) {
  var as = props.as,
      _props$nextAs = props.nextAs,
      nextAs = _props$nextAs === undefined ? [] : _props$nextAs;

  var _nextAs$slice = nextAs.slice(-1),
      lastElement = _nextAs$slice[0];

  if (typeof as === "string") {
    return as;
  }
  if (nextAs.length && typeof lastElement === "string") {
    return lastElement;
  }

  return "span";
};

var Heading = styled__default(Base$1).withConfig({
  displayName: "Heading"
})(["display:block;margin:0.5em 0 0.3em;font-size:", ";", ";"], styledTools.switchProp(getUnderlyingElement, {
  h1: "2em",
  h2: "1.75em",
  h3: "1.5em",
  h4: "1.25em",
  h5: "1em",
  h6: "0.75em"
}), styledTools.prop("theme.Heading"));

var Heading$1 = as("h1")(Heading);

var Image = styled__default(Base$1).withConfig({
  displayName: "Image"
})(["display:block;max-width:100%;", ";"], styledTools.prop("theme.Image"));

var Image$1 = as("img")(Image);

var Inline = styled__default(Base$1).withConfig({
  displayName: "Inline"
})(["display:inline;", ";"], styledTools.prop("theme.Inline"));

var Inline$1 = as("span")(Inline);

var InlineBlock = styled__default(Base$1).withConfig({
  displayName: "InlineBlock"
})(["display:inline-block;", ";"], styledTools.prop("theme.InlineBlock"));

var InlineBlock$1 = as("div")(InlineBlock);

var InlineFlex = styled__default(Flex$1).withConfig({
  displayName: "InlineFlex"
})(["display:inline-flex;", ";"], styledTools.prop("theme.InlineFlex"));

var InlineFlex$1 = as("div")(InlineFlex);

var Input = styled__default(Box$1).withConfig({
  displayName: "Input"
})(["display:block;width:100%;padding:0 0.5em;height:2.5em;background-color:white;&::placeholder{color:currentcolor;opacity:0.5;}textarea&{padding:0.5em;height:auto;}&[type=\"checkbox\"],&[type=\"radio\"]{display:inline-block;width:auto;height:auto;padding:0;}", ";"], styledTools.prop("theme.Input"));

Input.defaultProps = {
  type: "text"
};

var Input$1 = as("input")(Input);

var Label = styled__default(Base$1).withConfig({
  displayName: "Label"
})(["display:inline-block;", ";"], styledTools.prop("theme.Label"));

var Label$1 = as("label")(Label);

var Link = styled__default(Base$1).withConfig({
  displayName: "Link"
})(["display:inline-grid;grid-gap:0.25em;align-items:center;grid-auto-flow:column;color:#0366d6;text-decoration:none;&:hover{outline-width:0;text-decoration:underline;}", ";"], styledTools.prop("theme.Link"));

var Link$1 = as("a")(Link);

var List = styled__default(Base$1).withConfig({
  displayName: "List"
})(["list-style:none;", ";"], styledTools.prop("theme.List"));

List.defaultProps = {
  role: "list"
};

var List$1 = as("ul")(List);

var ListItem = styled__default(Base$1).withConfig({
  displayName: "ListItem"
})(["margin-bottom:0.35em;", ";"], styledTools.prop("theme.ListItem"));

ListItem.defaultProps = {
  role: "listitem"
};

var ListItem$1 = as("li")(ListItem);

List$1.Item = ListItem$1;

var Navigation = styled__default(Base$1).withConfig({
  displayName: "Navigation"
})(["width:100%;", ";"], styledTools.prop("theme.Navigation"));

var Navigation$1 = as("nav")(Navigation);

var Component$6 = function (_React$Component) {
  inherits(Component, _React$Component);

  function Component() {
    var _temp, _this, _ret;

    classCallCheck(this, Component);

    for (var _len = arguments.length, args = Array(_len), _key = 0; _key < _len; _key++) {
      args[_key] = arguments[_key];
    }

    return _ret = (_temp = (_this = possibleConstructorReturn(this, _React$Component.call.apply(_React$Component, [this].concat(args))), _this), _this.state = {}, _temp), possibleConstructorReturn(_this, _ret);
  }

  Component.prototype.componentDidMount = function componentDidMount() {
    var wrapper = document.createElement("div");
    document.body.appendChild(wrapper);
    this.setState({ wrapper: wrapper });
  };

  Component.prototype.componentWillUnmount = function componentWillUnmount() {
    document.body.removeChild(this.state.wrapper);
  };

  Component.prototype.render = function render() {
    var wrapper = this.state.wrapper;

    if (wrapper) {
      return ReactDOM.createPortal(React.createElement(Hidden$1, this.props), wrapper);
    }
    return null;
  };

  return Component;
}(React.Component);

var Overlay = styled__default(Component$6).withConfig({
  displayName: "Overlay"
})(["position:fixed;background-color:white;left:50%;top:50%;transform:translate(-50%,-50%);z-index:19900410;", ";"], styledTools.prop("theme.Overlay"));

Overlay.defaultProps = {
  role: "dialog",
  "aria-modal": true,
  hideOnEsc: true
};

var Overlay$1 = as("div")(Overlay);

var OverlayContainer = HiddenContainer;

var OverlayToggle = styled__default(HiddenToggle$1).withConfig({
  displayName: "OverlayToggle"
})(["", ";"], styledTools.prop("theme.OverlayToggle"));

var OverlayToggle$1 = as("button")(OverlayToggle);

var OverlayShow = styled__default(HiddenShow$1).withConfig({
  displayName: "OverlayShow"
})(["", ";"], styledTools.prop("theme.OverlayShow"));

var OverlayShow$1 = as("button")(OverlayShow);

var OverlayHide = styled__default(HiddenHide$1).withConfig({
  displayName: "OverlayHide"
})(["", ";"], styledTools.prop("theme.OverlayHide"));

var OverlayHide$1 = as("button")(OverlayHide);

Overlay$1.Container = OverlayContainer;
Overlay$1.Toggle = OverlayToggle$1;
Overlay$1.Show = OverlayShow$1;
Overlay$1.Hide = OverlayHide$1;

var Paragraph = styled__default(Base$1).withConfig({
  displayName: "Paragraph"
})(["&:not(:last-child){margin-bottom:1rem;}", ";"], styledTools.prop("theme.Paragraph"));

var Paragraph$1 = as("p")(Paragraph);

var opposites = {
  top: "bottom",
  right: "left",
  bottom: "top",
  left: "right"
};

var opposite = function opposite(_ref) {
  var pos = _ref.pos;
  return opposites[pos];
};

var perpendicular = function perpendicular(_ref2) {
  var pos = _ref2.pos;
  return pos === "left" || pos === "right" ? "top" : "left";
};

var perpendicularOpposite = function perpendicularOpposite(props) {
  return opposites[perpendicular(props)];
};

var perpendicularAxis = function perpendicularAxis(_ref3) {
  var pos = _ref3.pos;
  return pos === "left" || pos === "right" ? "Y" : "X";
};

var rotation = function rotation(_ref4) {
  var rotate = _ref4.rotate,
      pos = _ref4.pos,
      reverse = _ref4.reverse;

  if (!rotate) return null;
  var rotateZ = function rotateZ(value) {
    return "rotateZ(" + (reverse ? value + 180 : value) + "deg)";
  };
  var rotations = {
    top: rotateZ(0),
    right: rotateZ(90),
    bottom: rotateZ(180),
    left: rotateZ(270)
  };
  return rotations[pos];
};

var Perpendicular = styled__default(Base$1).withConfig({
  displayName: "Perpendicular"
})(["position:absolute;", ":calc(100% + ", ");transform:", ";", ";", ";"], opposite, styledTools.prop("gutter"), rotation, styledTools.switchProp("align", {
  start: styled.css(["", ":0;"], perpendicular),
  center: styled.css(["", ":50%;transform:translate", "(-50%) ", ";"], perpendicular, perpendicularAxis, rotation),
  end: styled.css(["", ":0;"], perpendicularOpposite)
}), styledTools.prop("theme.Perpendicular"));

Perpendicular.propTypes = {
  pos: PropTypes.oneOf(["top", "right", "bottom", "left"]),
  align: PropTypes.oneOf(["start", "center", "end"]),
  gutter: PropTypes.string,
  rotate: PropTypes.bool,
  reverse: PropTypes.bool
};

Perpendicular.defaultProps = {
  pos: "right",
  align: "center",
  gutter: "0.75rem"
};

var Perpendicular$1 = as("div")(Perpendicular);

var HiddenPerpendicularBox = Hidden$1.as([Perpendicular$1, Box$1]);

var Component$7 = function Component(props) {
  return React.createElement(HiddenPerpendicularBox, _extends({ id: props.popoverId }, props));
};

var Popover = styled__default(Component$7).withConfig({
  displayName: "Popover"
})(["user-select:auto;cursor:auto;color:inherit;background-color:white;padding:1em;z-index:999;outline:0;", ";"], styledTools.prop("theme.Popover"));

Popover.propTypes = {
  popoverId: PropTypes.string
};

Popover.defaultProps = {
  role: "group",
  pos: "bottom",
  align: "center",
  hideOnEsc: true
};

var Popover$1 = as("div")(Popover);

var PerpendicularArrowBox = Perpendicular$1.as([Arrow$1, Box$1]);

var PopoverArrow = styled__default(PerpendicularArrowBox).withConfig({
  displayName: "PopoverArrow"
})(["color:white;border:inherit;border-top:0;font-size:1.5em;", ";"], styledTools.prop("theme.PopoverArrow"));

PopoverArrow.defaultProps = {
  pos: "top",
  align: "center",
  gutter: "-1px",
  rotate: true,
  reverse: true
};

var PopoverArrow$1 = as("div")(PopoverArrow);

/* eslint-disable react/prefer-stateless-function */

var PopoverContainer = function (_React$Component) {
  inherits(PopoverContainer, _React$Component);

  function PopoverContainer() {
    var _temp, _this, _ret;

    classCallCheck(this, PopoverContainer);

    for (var _len = arguments.length, args = Array(_len), _key = 0; _key < _len; _key++) {
      args[_key] = arguments[_key];
    }

    return _ret = (_temp = (_this = possibleConstructorReturn(this, _React$Component.call.apply(_React$Component, [this].concat(args))), _this), _this.popoverId = uniqueId("popover"), _temp), possibleConstructorReturn(_this, _ret);
  }

  PopoverContainer.prototype.render = function render() {
    return React.createElement(HiddenContainer, _extends({}, this.props, {
      initialState: _extends({ popoverId: this.popoverId }, this.props.initialState)
    }));
  };

  return PopoverContainer;
}(React.Component);

PopoverContainer.propTypes = {
  initialState: PropTypes.object
};

var Component$8 = function Component(props) {
  return React.createElement(HiddenToggle$1, _extends({
    "aria-expanded": props.visible,
    "aria-controls": props.popoverId,
    "aria-haspopup": true
  }, props));
};

var PopoverToggle = styled__default(Component$8).withConfig({
  displayName: "PopoverToggle"
})(["", ";"], styledTools.prop("theme.PopoverToggle"));

PopoverToggle.propTypes = {
  popoverId: PropTypes.string.isRequired,
  visible: PropTypes.bool
};

var PopoverToggle$1 = as("button")(PopoverToggle);

var PopoverShow = styled__default(HiddenShow$1).withConfig({
  displayName: "PopoverShow"
})(["", ";"], styledTools.prop("theme.PopoverShow"));

var PopoverShow$1 = as("button")(PopoverShow);

var PopoverHide = styled__default(HiddenHide$1).withConfig({
  displayName: "PopoverHide"
})(["", ";"], styledTools.prop("theme.PopoverHide"));

var PopoverHide$1 = as("button")(PopoverHide);

Popover$1.Arrow = PopoverArrow$1;
Popover$1.Container = PopoverContainer;
Popover$1.Toggle = PopoverToggle$1;
Popover$1.Show = PopoverShow$1;
Popover$1.Hide = PopoverHide$1;

var Shadow = styled__default(Fit$1).withConfig({
  displayName: "Shadow"
})(["border-radius:inherit;pointer-events:none;box-shadow:", ";&&&{margin:0;}", ";"], styledTools.withProp("depth", function (d) {
  return "0 " + d * 2 + "px " + d * 4 + "px rgba(0, 0, 0, 0.2)";
}), styledTools.prop("theme.Shadow"));

Shadow.propTypes = {
  depth: PropTypes.number
};

Shadow.defaultProps = {
  depth: 2
};

var Shadow$1 = as("div")(Shadow);

var Sidebar = styled__default(Overlay$1).withConfig({
  displayName: "Sidebar"
})(["top:0;height:100vh;transform:none;overflow:auto;left:", ";right:", ";", ";"], styledTools.ifProp({ align: "right" }, "auto", 0), styledTools.ifProp({ align: "right" }, 0, "auto"), styledTools.prop("theme.Sidebar"));

Sidebar.propTypes = {
  align: PropTypes.oneOf(["left", "right"])
};

Sidebar.defaultProps = {
  align: "left"
};

var Sidebar$1 = as("div")(Sidebar);

var SidebarContainer = OverlayContainer;

var SidebarToggle = styled__default(OverlayToggle$1).withConfig({
  displayName: "SidebarToggle"
})(["", ";"], styledTools.prop("theme.SidebarToggle"));

var SidebarToggle$1 = as("button")(SidebarToggle);

var SidebarShow = styled__default(OverlayShow$1).withConfig({
  displayName: "SidebarShow"
})(["", ";"], styledTools.prop("theme.SidebarShow"));

var SidebarShow$1 = as("button")(SidebarShow);

var SidebarHide = styled__default(OverlayHide$1).withConfig({
  displayName: "SidebarHide"
})(["", ";"], styledTools.prop("theme.SidebarHide"));

var SidebarHide$1 = as("button")(SidebarHide);

Sidebar$1.Container = SidebarContainer;
Sidebar$1.Toggle = SidebarToggle$1;
Sidebar$1.Show = SidebarShow$1;
Sidebar$1.Hide = SidebarHide$1;

/* eslint-disable no-param-reassign */
var createElementRef = function createElementRef(scope, property) {
  return function (element) {
    scope[property] = element;
    if (scope.props && scope.props.elementRef) {
      scope.props.elementRef(element);
    }
  };
};

var noop = function noop() {};

var Component$9 = function (_React$Component) {
  inherits(Component, _React$Component);

  function Component(props) {
    classCallCheck(this, Component);

    var _this = possibleConstructorReturn(this, _React$Component.call(this, props));

    var _this$props = _this.props,
        register = _this$props.register,
        step = _this$props.step,
        order = _this$props.order;

    register(step, order);
    return _this;
  }

  Component.prototype.componentDidMount = function componentDidMount() {
    var _props = this.props,
        step = _props.step,
        onEnter = _props.onEnter,
        current = _props.current,
        indexOf = _props.indexOf;


    if (onEnter && current === indexOf(step)) {
      onEnter(this.element);
    }
  };

  Component.prototype.componentDidUpdate = function componentDidUpdate(prevProps) {
    var _props2 = this.props,
        step = _props2.step,
        update = _props2.update,
        order = _props2.order,
        indexOf = _props2.indexOf,
        current = _props2.current,
        onEnter = _props2.onEnter,
        onExit = _props2.onExit;


    if (prevProps.step !== step || prevProps.order !== order) {
      update(prevProps.step, step, order);
    }

    if (prevProps.current !== current) {
      var index = indexOf(step);
      if (onEnter && prevProps.current !== index && current === index) {
        onEnter(this.element);
      } else if (onExit && prevProps.current === index) {
        onExit(this.element);
      }
    }
  };

  Component.prototype.componentWillUnmount = function componentWillUnmount() {
    var _props3 = this.props,
        step = _props3.step,
        onExit = _props3.onExit,
        current = _props3.current,
        indexOf = _props3.indexOf,
        unregister = _props3.unregister;


    if (onExit && current === indexOf(step)) {
      onExit(this.element);
    }

    unregister(step);
  };

  Component.prototype.render = function render() {
    var _props4 = this.props,
        current = _props4.current,
        indexOf = _props4.indexOf,
        step = _props4.step;

    return React.createElement(Hidden$1, _extends({
      destroy: true,
      visible: current === indexOf(step)
    }, this.props, {
      elementRef: createElementRef(this, "element")
    }));
  };

  return Component;
}(React.Component);

var Step = styled__default(Component$9).withConfig({
  displayName: "Step"
})(["", ";"], styledTools.prop("theme.Step"));

Step.propTypes = {
  step: PropTypes.string.isRequired,
  current: PropTypes.number.isRequired,
  register: PropTypes.func.isRequired,
  update: PropTypes.func.isRequired,
  unregister: PropTypes.func.isRequired,
  indexOf: PropTypes.func.isRequired,
  order: PropTypes.number,
  onEnter: PropTypes.func,
  onExit: PropTypes.func
};

Step.defaultProps = {
  register: noop,
  update: noop,
  unregister: noop,
  indexOf: noop
};

var Step$1 = as("div")(Step);

/* eslint-disable react/no-unused-prop-types */

var initialState$1 = {
  loop: false,
  ids: [],
  current: -1,
  ordered: {}
};

var getCurrentId = function getCurrentId() {
  return function (state) {
    return state.ids[state.current];
  };
};

var hasPrevious = function hasPrevious() {
  return function (state) {
    return state.ids.length > 1 && !!state.ids[state.current - 1];
  };
};

var hasNext = function hasNext() {
  return function (state) {
    return state.ids.length > 1 && !!state.ids[state.current + 1];
  };
};

var indexOf = function indexOf(idOrIndex) {
  return function (state) {
    return typeof idOrIndex === "number" ? idOrIndex : state.ids.indexOf(idOrIndex);
  };
};

var isCurrent = function isCurrent(idOrIndex) {
  return function (state) {
    return state.current >= 0 && state.current === indexOf(idOrIndex)(state);
  };
};

var show$1 = function show(idOrIndex) {
  return function (state) {
    return {
      current: indexOf(idOrIndex)(state)
    };
  };
};

var hide$1 = function hide() {
  return function () {
    return { current: -1 };
  };
};

var toggle$1 = function toggle(idOrIndex) {
  return function (state) {
    return isCurrent(idOrIndex)(state) ? hide$1()(state) : show$1(idOrIndex)(state);
  };
};

var previous = function previous() {
  return function (state) {
    if (hasPrevious()(state)) {
      return { current: state.current - 1 };
    }
    if (state.loop) {
      return { current: state.ids.length - 1 };
    }
    return {};
  };
};

var next = function next() {
  return function (state) {
    if (hasNext()(state)) {
      return { current: state.current + 1 };
    }
    if (state.loop) {
      return { current: 0 };
    }
    return {};
  };
};

var reorder = function reorder(id) {
  var order = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : 0;
  return function (state) {
    var _babelHelpers$extends;

    var ordered = _extends({}, state.ordered, (_babelHelpers$extends = {}, _babelHelpers$extends[id] = order, _babelHelpers$extends));
    var ids = state.ids.slice().sort(function (a, b) {
      return (ordered[a] || 0) - (ordered[b] || 0);
    });
    return _extends({
      ordered: ordered,
      ids: ids
    }, isCurrent(id)(state) ? show$1(id)(_extends({}, state, { ids: ids })) : {});
  };
};

var register = function register(id) {
  var order = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : 0;
  return function (state) {
    var ids = state.ids.indexOf(id) >= 0 ? state.ids : [].concat(state.ids, [id]);
    return reorder(id, order)(_extends({}, state, { ids: ids }));
  };
};

var unregister = function unregister(id) {
  return function (state) {
    var index = indexOf(id)(state);
    if (index === -1) {
      return {};
    }

    var ordered = omit(state.ordered, state.ids[index]);
    var ids = [].concat(state.ids.slice(0, index), state.ids.slice(index + 1));

    if (isCurrent(id)(state) && !hasNext()(state)) {
      if (hasPrevious()(state)) {
        return _extends({}, previous()(state), { ids: ids, ordered: ordered });
      }
      return _extends({}, hide$1()(state), { ids: ids, ordered: ordered });
    }
    if (state.current >= ids.length) {
      return { current: ids.length - 1, ids: ids, ordered: ordered };
    }
    return { ids: ids, ordered: ordered };
  };
};

var update = function update(id, nextId, orderArg) {
  return function (state) {
    var order = typeof orderArg !== "undefined" ? orderArg : state.ordered[id];
    var idChanged = id !== nextId;
    var orderChanged = order !== state.ordered[id];

    if (!idChanged && !orderChanged) return {};

    var overridingId = idChanged && state.ids.indexOf(nextId) >= 0;

    if (overridingId) {
      var nextOrderChanged = order !== state.ordered[nextId];
      var nextState = nextOrderChanged ? reorder(nextId, order)(state) : {};
      return unregister(id)(_extends({}, state, nextState));
    }

    var index = indexOf(id)(state);
    var ids = [].concat(state.ids.slice(0, index), [nextId], state.ids.slice(index + 1));
    return reorder(nextId, order)(_extends({}, state, { ids: ids }));
  };
};

var selectors = {
  getCurrentId: getCurrentId,
  hasPrevious: hasPrevious,
  hasNext: hasNext,
  indexOf: indexOf,
  isCurrent: isCurrent
};

var actions = {
  show: show$1,
  hide: hide$1,
  toggle: toggle$1,
  previous: previous,
  next: next,
  reorder: reorder,
  register: register,
  unregister: unregister,
  update: update
};

// istanbul ignore next
var StepContainer = function StepContainer(props) {
  return React.createElement(constate.Container, _extends({}, props, {
    initialState: _extends({}, initialState$1, props.initialState),
    selectors: _extends({}, selectors, props.selectors),
    actions: _extends({}, actions, props.actions)
  }));
};

StepContainer.propTypes = {
  initialState: PropTypes.object,
  actions: PropTypes.objectOf(PropTypes.func),
  selectors: PropTypes.objectOf(PropTypes.func)
};

var toggle$2 = function toggle(props) {
  return function () {
    return props.toggle && props.toggle(props.step);
  };
};
var Component$a = function Component(props) {
  return React.createElement(HiddenToggle$1, _extends({}, props, { toggle: toggle$2(props) }));
};

var StepToggle = styled__default(Component$a).withConfig({
  displayName: "StepToggle"
})(["", ";"], styledTools.prop("theme.StepToggle"));

StepToggle.propTypes = {
  toggle: PropTypes.func.isRequired,
  step: PropTypes.string.isRequired
};

var StepToggle$1 = as("button")(StepToggle);

var show$2 = function show(props) {
  return function () {
    return props.show && props.show(props.step);
  };
};
var Component$b = function Component(props) {
  return React.createElement(HiddenShow$1, _extends({}, props, { show: show$2(props) }));
};

var StepShow = styled__default(Component$b).withConfig({
  displayName: "StepShow"
})(["", ";"], styledTools.prop("theme.StepShow"));

StepShow.propTypes = {
  show: PropTypes.func.isRequired,
  step: PropTypes.string.isRequired
};

var StepShow$1 = as("button")(StepShow);

var StepHide = styled__default(HiddenHide$1).withConfig({
  displayName: "StepHide"
})(["", ";"], styledTools.prop("theme.StepHide"));

var StepHide$1 = as("button")(StepHide);

var Component$c = function Component(_ref) {
  var onClick = _ref.onClick,
      props = objectWithoutProperties(_ref, ["onClick"]);
  return React.createElement(Base$1, _extends({
    onClick: callAll(props.next, onClick),
    disabled: !props.loop && props.hasNext && !props.hasNext()
  }, props));
};

var StepNext = styled__default(Component$c).withConfig({
  displayName: "StepNext"
})(["", ";"], styledTools.prop("theme.StepNext"));

StepNext.propTypes = {
  next: PropTypes.func.isRequired,
  hasNext: PropTypes.func,
  loop: PropTypes.bool,
  onClick: PropTypes.func
};

var StepNext$1 = as("button")(StepNext);

var Component$d = function Component(_ref) {
  var onClick = _ref.onClick,
      props = objectWithoutProperties(_ref, ["onClick"]);
  return React.createElement(Base$1, _extends({
    onClick: callAll(props.previous, onClick),
    disabled: !props.loop && props.hasPrevious && !props.hasPrevious()
  }, props));
};

var StepPrevious = styled__default(Component$d).withConfig({
  displayName: "StepPrevious"
})(["", ";"], styledTools.prop("theme.StepPrevious"));

StepPrevious.propTypes = {
  previous: PropTypes.func.isRequired,
  hasPrevious: PropTypes.func,
  loop: PropTypes.bool,
  onClick: PropTypes.func
};

var StepPrevious$1 = as("button")(StepPrevious);

Step$1.Container = StepContainer;
Step$1.Toggle = StepToggle$1;
Step$1.Show = StepShow$1;
Step$1.Hide = StepHide$1;
Step$1.Next = StepNext$1;
Step$1.Previous = StepPrevious$1;

var Table = styled__default(Base$1).withConfig({
  displayName: "Table"
})(["display:table;table-layout:fixed;border-collapse:collapse;background-color:white;border:1px solid #bbb;line-height:200%;", ";"], styledTools.prop("theme.Table"));

Table.defaultProps = {
  role: "table"
};

var Table$1 = as("table")(Table);

var TableBody = styled__default(Base$1).withConfig({
  displayName: "TableBody"
})(["display:table-row-group;border:inherit;", ";"], styledTools.prop("theme.TableBody"));

TableBody.defaultProps = {
  role: "rowgroup"
};

var TableBody$1 = as("tbody")(TableBody);

var TableCaption = styled__default(Base$1).withConfig({
  displayName: "TableCaption"
})(["display:table-caption;text-transform:uppercase;font-size:0.9em;color:#999;", ";"], styledTools.prop("theme.TableCaption"));

var TableCaption$1 = as("caption")(TableCaption);

var Component$e = function Component(props) {
  return React.createElement(Base$1, _extends({
    as: props.header ? "th" : "td",
    role: props.header ? "columnheader" : "cell"
  }, props));
};

var TableCell = styled__default(Base$1).withConfig({
  displayName: "TableCell"
})(["display:table-cell;border:inherit;padding:0 8px;vertical-align:middle;", ";", ";"], styledTools.ifProp("header", styled.css(["font-weight:bold;background-color:rgba(0,0,0,0.05);"])), styledTools.prop("theme.TableCell"));

TableCell.propTypes = {
  header: PropTypes.bool
};

var TableCell$1 = as(Component$e)(TableCell);

var TableColumn = styled__default(Base$1).withConfig({
  displayName: "TableColumn"
})(["display:table-column;", ";"], styledTools.prop("theme.TableColumn"));

var TableColumn$1 = as("col")(TableColumn);

var TableColumnGroup = styled__default(Base$1).withConfig({
  displayName: "TableColumnGroup"
})(["display:table-column-group;", ";"], styledTools.prop("theme.TableColumnGroup"));

var TableColumnGroup$1 = as("colgroup")(TableColumnGroup);

var TableFoot = styled__default(Base$1).withConfig({
  displayName: "TableFoot"
})(["display:table-footer-group;border:inherit;", ";"], styledTools.prop("theme.TableFoot"));

TableFoot.defaultProps = {
  role: "rowgroup"
};

var TableFoot$1 = as("tfoot")(TableFoot);

var TableHead = styled__default(Base$1).withConfig({
  displayName: "TableHead"
})(["display:table-header-group;border:inherit;", ";"], styledTools.prop("theme.TableHead"));

TableHead.defaultProps = {
  role: "rowgroup"
};

var TableHead$1 = as("thead")(TableHead);

var TableRow = styled__default(Base$1).withConfig({
  displayName: "TableRow"
})(["display:table-row;border:inherit;", ";"], styledTools.prop("theme.TableRow"));

TableRow.defaultProps = {
  role: "row"
};

var TableRow$1 = as("tr")(TableRow);

Table$1.Body = TableBody$1;
Table$1.Caption = TableCaption$1;
Table$1.Cell = TableCell$1;
Table$1.Column = TableColumn$1;
Table$1.ColumnGroup = TableColumnGroup$1;
Table$1.Foot = TableFoot$1;
Table$1.Head = TableHead$1;
Table$1.Row = TableRow$1;

var Tabs = styled__default(Base$1).withConfig({
  displayName: "Tabs"
})(["display:flex;align-items:center;list-style:none;@media screen and (max-width:640px){overflow-x:auto;}", ";"], styledTools.prop("theme.Tabs"));

Tabs.defaultProps = {
  role: "tablist"
};

var Tabs$1 = as("ul")(Tabs);

var initialState$2 = {
  loop: true,
  current: 0
};

// istanbul ignore next
var TabsContainer = function TabsContainer(props) {
  return React.createElement(StepContainer, _extends({}, props, {
    initialState: _extends({}, initialState$2, props.initialState)
  }));
};

TabsContainer.propTypes = {
  initialState: PropTypes.object
};

var Component$f = function (_React$Component) {
  inherits(Component, _React$Component);

  function Component() {
    var _temp, _this, _ret;

    classCallCheck(this, Component);

    for (var _len = arguments.length, args = Array(_len), _key = 0; _key < _len; _key++) {
      args[_key] = arguments[_key];
    }

    return _ret = (_temp = (_this = possibleConstructorReturn(this, _React$Component.call.apply(_React$Component, [this].concat(args))), _this), _this.show = function () {
      var _this$props = _this.props,
          show = _this$props.show,
          isCurrent = _this$props.isCurrent,
          tab = _this$props.tab;

      if (!isCurrent(tab)) {
        show(tab);
      }
    }, _this.keyDown = function (e) {
      var keyMap = {
        ArrowLeft: _this.props.previous,
        ArrowRight: _this.props.next
      };
      if (keyMap[e.key]) {
        e.preventDefault();
        keyMap[e.key]();
      }
    }, _temp), possibleConstructorReturn(_this, _ret);
  }

  Component.prototype.componentDidUpdate = function componentDidUpdate(prevProps) {
    var _props = this.props,
        current = _props.current,
        isCurrent = _props.isCurrent,
        tab = _props.tab;


    if (prevProps.current !== current && isCurrent(tab)) {
      this.element.focus();
    }
  };

  Component.prototype.render = function render() {
    var _props2 = this.props,
        isCurrent = _props2.isCurrent,
        tab = _props2.tab,
        className = _props2.className,
        onClick = _props2.onClick,
        onFocus = _props2.onFocus,
        onKeyDown = _props2.onKeyDown;


    var active = isCurrent(tab);
    var activeClassName = active ? "active" : "";
    var finalClassName = [className, activeClassName].filter(function (c) {
      return !!c;
    }).join(" ");

    return React.createElement(Step$1, _extends({
      id: tab + "Tab",
      step: tab,
      active: active,
      "aria-selected": active,
      "aria-controls": tab + "Panel",
      tabIndex: active ? 0 : -1,
      visible: true
    }, this.props, {
      onClick: callAll(this.show, onClick),
      onFocus: callAll(this.show, onFocus),
      onKeyDown: callAll(this.keyDown, onKeyDown),
      className: finalClassName,
      elementRef: createElementRef(this, "element")
    }));
  };

  return Component;
}(React.Component);

var TabsTab = styled__default(Component$f).withConfig({
  displayName: "TabsTab"
})(["display:inline-flex;position:relative;flex:1;user-select:none;outline:none;align-items:center;white-space:nowrap;justify-content:center;text-decoration:none;height:2.5em;padding:0 0.5em;min-width:2.5em;&.active{font-weight:bold;}&[disabled]{pointer-events:none;}", ";"], styledTools.prop("theme.TabsTab"));

TabsTab.propTypes = {
  tab: PropTypes.string.isRequired,
  register: PropTypes.func.isRequired,
  update: PropTypes.func.isRequired,
  unregister: PropTypes.func.isRequired,
  isCurrent: PropTypes.func.isRequired,
  show: PropTypes.func.isRequired,
  next: PropTypes.func.isRequired,
  previous: PropTypes.func.isRequired,
  className: PropTypes.string,
  disabled: PropTypes.bool,
  onClick: PropTypes.func,
  onFocus: PropTypes.func,
  onKeyDown: PropTypes.func
};

var noop$1 = function noop() {};

TabsTab.defaultProps = {
  role: "tab",
  register: noop$1,
  update: noop$1,
  unregister: noop$1,
  isCurrent: noop$1,
  show: noop$1,
  next: noop$1,
  previous: noop$1
};

var TabsTab$1 = as("li")(TabsTab);

var Component$g = function Component(props) {
  var isCurrent = props.isCurrent,
      tab = props.tab;

  return React.createElement(Hidden$1, _extends({
    id: tab + "Panel",
    "aria-labelledby": tab + "Tab",
    destroy: true,
    visible: isCurrent && isCurrent(tab)
  }, props));
};

hoistNonReactStatics(Component$g, Hidden$1);

var TabsPanel = styled__default(Component$g).withConfig({
  displayName: "TabsPanel"
})(["", ";"], styledTools.prop("theme.TabsPanel"));

TabsPanel.propTypes = {
  tab: PropTypes.string.isRequired,
  isCurrent: PropTypes.func.isRequired
};

TabsPanel.defaultProps = {
  role: "tabpanel"
};

var TabsPanel$1 = as("div")(TabsPanel);

var TabsNext = styled__default(StepNext$1).withConfig({
  displayName: "TabsNext"
})(["", ";"], styledTools.prop("theme.TabsNext"));

var TabsNext$1 = as("button")(TabsNext);

var TabsPrevious = styled__default(StepPrevious$1).withConfig({
  displayName: "TabsPrevious"
})(["", ";"], styledTools.prop("theme.TabsPrevious"));

var TabsPrevious$1 = as("button")(TabsPrevious);

Tabs$1.Container = TabsContainer;
Tabs$1.Tab = TabsTab$1;
Tabs$1.Panel = TabsPanel$1;
Tabs$1.Next = TabsNext$1;
Tabs$1.Previous = TabsPrevious$1;

var Tooltip = styled__default(Perpendicular$1).withConfig({
  displayName: "Tooltip"
})(["pointer-events:none;opacity:0;white-space:nowrap;text-transform:none;font-size:0.85em;text-align:center;color:white;background-color:rgba(0,0,0,0.85);border-radius:0.15384em;padding:0.75em 1em;*:hover > &,*:focus > &{opacity:1;}", ";"], styledTools.prop("theme.Tooltip"));

Tooltip.defaultProps = {
  role: "tooltip",
  pos: "top",
  align: "center"
};

var Tooltip$1 = as("div")(Tooltip);

var PerpendicularArrow = Perpendicular$1.as(Arrow$1);

var TooltipArrow = styled__default(PerpendicularArrow).withConfig({
  displayName: "TooltipArrow"
})(["pointer-events:none;color:rgba(0,0,0,0.85);border:inherit;font-size:1.1764705882em;", ";"], styledTools.prop("theme.TooltipArrow"));

TooltipArrow.defaultProps = {
  pos: "bottom",
  align: "center",
  gutter: "0px",
  rotate: true,
  reverse: true
};

var TooltipArrow$1 = as("div")(TooltipArrow);

Tooltip$1.Arrow = TooltipArrow$1;

exports.styled = styled__default;
exports.css = styled.css;
exports.keyframes = styled.keyframes;
exports.injectGlobal = styled.injectGlobal;
exports.isStyledComponent = styled.isStyledComponent;
exports.consolidateStreamedStyles = styled.consolidateStreamedStyles;
exports.ThemeProvider = styled.ThemeProvider;
exports.withTheme = styled.withTheme;
exports.ServerStyleSheet = styled.ServerStyleSheet;
exports.StyleSheetManager = styled.StyleSheetManager;
exports.Container = constate.Container;
exports.Provider = constate.Provider;
exports.Consumer = constate.Consumer;
exports.as = as;
exports.default = as;
exports.Arrow = Arrow$1;
exports.Backdrop = Backdrop$1;
exports.Base = Base$1;
exports.Block = Block$1;
exports.Blockquote = Blockquote$1;
exports.Box = Box$1;
exports.Button = Button$1;
exports.Card = Card$1;
exports.Code = Code$1;
exports.Divider = Divider$1;
exports.Field = Field$1;
exports.Fit = Fit$1;
exports.Flex = Flex$1;
exports.Grid = Grid$1;
exports.Group = Group$1;
exports.Heading = Heading$1;
exports.Hidden = Hidden$1;
exports.Image = Image$1;
exports.Inline = Inline$1;
exports.InlineBlock = InlineBlock$1;
exports.InlineFlex = InlineFlex$1;
exports.Input = Input$1;
exports.Label = Label$1;
exports.Link = Link$1;
exports.List = List$1;
exports.Navigation = Navigation$1;
exports.Overlay = Overlay$1;
exports.Paragraph = Paragraph$1;
exports.Perpendicular = Perpendicular$1;
exports.Popover = Popover$1;
exports.Shadow = Shadow$1;
exports.Sidebar = Sidebar$1;
exports.Step = Step$1;
exports.Table = Table$1;
exports.Tabs = Tabs$1;
exports.Tooltip = Tooltip$1;
